@@ -363,7 +363,7 @@ their first non-blank character are ignored as comments.
 
 and the options are loaded into a hash used by all sites 
 (submodules) that support them.  Valid options include 
-I<-debug> => [0|1|2]> and most of the L<LWP::UserAgent> options.  
+I<-debug> => [0|1|2] and most of the L<LWP::UserAgent> options.  
 
 =item ~/.config/StreamFinder/I<submodule>/config
 
@@ -380,7 +380,7 @@ line in the formats below:
 
 and the options are loaded into a hash used only by the specific 
 (submodule) specified.  Valid options include 
-I<-debug> => [0|1|2]> and most of the L<LWP::UserAgent> options.
+I<-debug> => [0|1|2] and most of the L<LWP::UserAgent> options.
 
 NOTE:  Options specified here override any specified in I<~/.config/StreamFinder/config>.
 
@@ -485,7 +485,7 @@ use strict;
 use warnings;
 use vars qw(@ISA @EXPORT $VERSION);
 
-our $VERSION = '1.70';
+our $VERSION = '1.71';
 our $DEBUG = 0;
 
 require Exporter;
