@@ -245,7 +245,7 @@ their first non-blank character are ignored as comments.
 
 and the options are loaded into a hash used only by the specific 
 (submodule) specified.  Valid options include 
-I<-debug> => [0|1|2]> and most of the L<LWP::UserAgent> options.  
+I<-debug> => [0|1|2] and most of the L<LWP::UserAgent> options.  
 Blank lines and lines starting with a "#" sign are ignored.
 
 Options specified here override any specified in I<~/.config/StreamFinder/config>.
@@ -259,7 +259,7 @@ Each option is specified on a separate line in the format below:
 
 and the options are loaded into a hash used by all sites 
 (submodules) that support them.  Valid options include 
-I<-debug> => [0|1|2]> and most of the L<LWP::UserAgent> options.
+I<-debug> => [0|1|2] and most of the L<LWP::UserAgent> options.
 
 =back
 
