@@ -135,7 +135,8 @@ If I<-format> is specified, it should be a valid "I<youtube-dl -f>" format
 string (see the youtube-dl manpage for details).  Examples:  
 "I<mp4[height<=720]/best[height<=720]>" which limits videos to 720p, or 
 "bestaudio" to download only audio streams.
-Default is "mp4", but if no streams are found, it then tries all.
+Default is "I<mp4>", but if no streams are found, it then tries all, 
+unless I<-formatonly> is specified.
 
 If I<-formatonly> is specified (set to 1 (true)), then if no streams match 
 the specified I<-format> argument (default "I<mp4>"), then no streams will 
@@ -145,7 +146,8 @@ argument.  Default is 0 (false / unset).
 If I<-fast> is specified (set to 1 (true)), a separate probe of the 
 page to fetch the video's title and artist is skipped.  This is useful 
 if you know the video is NOT a YouTube video or you don't care about 
-the artist (youtube channel's owner), artist icon, fields, etc.
+the artist (youtube channel's owner), artist icon, fields, etc.  
+Default is 0 (false / unset).
 
 If I<-noiframes>, if set to 1 (I<true>) means only 
 process actual video URLs, not search the page for an iframe containing 
@@ -166,13 +168,16 @@ to send to youtube-dl's optional "I<--user-agent>" argument.  NOTE:  This is
 completely separate from the I<-agent> option used by some other StreamFinder 
 modules for fetching pages and streams from their respective sites, as that 
 argument is used by LWP::UserAgent (along with some other options), and is NOT 
-passed to youtube-dl, though they represent the same kind of user-agent string!
+passed to youtube-dl, though they represent the same kind of user-agent string! 
+Default is I<-none-> (youtube-dl or the alternate program may use it's 
+own default).
 
 The optional I<-userid> and I<-userpw> arguments allow specifying a Youtube 
-login (for fetching videos, ie. paid ones that require one).
+login (for fetching videos, ie. paid ones that require one).  
+Defaults are I<-none-> (no userid or password specified).
 
 The optional I<-youtube-dl> argument allows specifying an alternate stream-
-parser program in lieu of "youtube-dl" (Default:  "youtube-dl").  A current 
+parser program in lieu of "youtube-dl" (Default:  "I<youtube-dl>").  A current 
 such alternate program is "yt-dlp".  If the program is not in the user's 
 executable I<PATH>, the full path can be included with the program name here.
 
@@ -181,7 +186,7 @@ to be passed to the external youtube-dl (or yt-dlp, etc.) program.  NOTE:
 Unless this program changes it's valid arguments or you select an alternate 
 program that requires slightly different arguments, you should NOT use this 
 argument, as the DEFAULT is:  
-"I<--get-url --get-format --get-thumbnail --get-title --get-description>", 
+"I<--get-url --get-format --get-thumbnail --get-title --get-description --get-id>", 
 which are the I<currently> required arguments for this module to function 
 properly!  Instead, if you wish to include additional arguments, you should 
 use the I<-youtube-dl-add-args> option to append them to this required list, 
@@ -192,7 +197,8 @@ The optional I<-youtube-dl-add-args> argument allows you to add additional
 arguments to be passed to the external youtube-dl (or yt-dlp, etc.) program.  
 See both the I<-youtube-dl-args> argument description and the manpage for 
 youtube-dl or whatever alternative external program you use to extract 
-video streams for valid arguments for possible inclusion here.
+video streams for valid arguments for possible inclusion here.  
+Default is I<-none-> (no additional arguments).
 
 Additional (general StreamFinder) options:
 
@@ -303,7 +309,7 @@ their first non-blank character are ignored as comments.
 
 and the options are loaded into a hash used only by the specific 
 (submodule) specified.  Valid options include 
-I<-debug> => [0|1|2]> and most of the L<LWP::UserAgent> options.  
+I<-debug> => [0|1|2] and most of the L<LWP::UserAgent> options.  
 
 Options specified here override any specified in I<~/.config/StreamFinder/config>.
 
@@ -316,7 +322,7 @@ Each option is specified on a separate line in the format below:
 
 and the options are loaded into a hash used by all sites 
 (submodules) that support them.  Valid options include 
-I<-debug> => [0|1|2]> and most of the L<LWP::UserAgent> options.
+I<-debug> => [0|1|2] and most of the L<LWP::UserAgent> options.
 
 =back
 
@@ -435,7 +441,7 @@ sub new
 	$DEBUG = $self->{'debug'}  if (defined $self->{'debug'});
 	$self->{'noiframes'} = 0  unless (defined $self->{'noiframes'});
 	#DEFAULT YOUTUBE-DL ARGUMENTS:
-	$self->{'youtube-dl-args'} = '--get-url --get-format --get-thumbnail --get-title --get-description'
+	$self->{'youtube-dl-args'} = '--get-url --get-format --get-thumbnail --get-title --get-description --get-id'
 			unless (defined $self->{'youtube-dl-args'});
 
 	while (@_) {
@@ -576,6 +582,7 @@ RETRYIT:
 		$_ = shift(@ytdldata);
 		$self->{'title'} ||= $_;
 	}
+	$self->{'_ytID'} = shift(@ytdldata)  if ($ytdlArgs =~ /\-\-get\-id\b/ && $ytdldata[0] =~ /^[a-z0-9]{11}$/i);
 	my $fmtline = ($ytdldata[$#ytdldata] =~ m#^https?\:\/\/#) ? '-none' : pop(@ytdldata);  #LAST LINE IS (USUALLY) THE LIST OF FORMATS RETURNED.
 	my @fmtsfound = split(/\+/, $fmtline);
 	$self->{'description'} = '';
@@ -604,48 +611,59 @@ RETRYIT:
 
 	#NOW MANUALLY SCAN YOUTUBE PAGE TO TRY TO GET artist, description, year, ETC. DIRECTLY FROM PAGE (IF A YOUTUBE SITE):
 
-	unless ($self->{'fast'} || $url2fetch !~ /\b(?:youtube\.|youtu.be|ytimg\.)\b/) {
-		print STDERR "-2 FETCHING SCREEN URL=$url2fetch= ID=".$self->{'id'}."=\n"  if ($DEBUG);
-		my $ua = LWP::UserAgent->new(@{$self->{'_userAgentOps'}});		
-		$ua->timeout($self->{'timeout'});
-		$ua->cookie_jar({});
-		$ua->env_proxy;
-		my $html = '';
-		my $response = $ua->get($url2fetch);
-		if ($response->is_success) {
-			$html = $response->decoded_content;
-		} else {
-			print STDERR $response->status_line  if ($DEBUG);
-			my $no_wget = system('wget','-V');
-			unless ($no_wget) {
-				print STDERR "\n..trying wget...\n"  if ($DEBUG);
-				$html = `wget -t 2 -T 20 -O- -o /dev/null \"$url2fetch\" 2>/dev/null `;
+	unless ($self->{'fast'}) {   #(FAST MEANS SKIP SCRAPING YOUTUBE PAGE FOR ADDTL. METADATA)
+		$try = 0;
+RETRYPAGE:
+		print STDERR "----(try2=$try= FETCHURL=$url2fetch=\n"  if ($DEBUG);
+		if ($url2fetch =~ /\b(?:youtube\.|youtu.be|ytimg\.)\b/) {  #WE'RE A YOUTUBE PAGE, FETCH METADATA:
+			print STDERR "-2 (TRY=$try) FETCHING SCREEN URL=$url2fetch= ID=".$self->{'id'}."=\n"  if ($DEBUG);
+			my $ua = LWP::UserAgent->new(@{$self->{'_userAgentOps'}});		
+			$ua->timeout($self->{'timeout'});
+			$ua->cookie_jar({});
+			$ua->env_proxy;
+			my $html = '';
+			my $response = $ua->get($url2fetch);
+			if ($response->is_success) {
+				$html = $response->decoded_content;
+			} else {
+				print STDERR $response->status_line  if ($DEBUG);
+				my $no_wget = system('wget','-V');
+				unless ($no_wget) {
+					print STDERR "\n..trying wget...\n"  if ($DEBUG);
+					$html = `wget -t 2 -T 20 -O- -o /dev/null \"$url2fetch\" 2>/dev/null `;
+				}
 			}
+			$html =~ s/\\\"/\&quot\;/gs;
+			if ($html =~ s#\]\}\,\"title\"\:\{\"runs\"\:\[\{\"text\"\:\"([^\"]+)\"\,\"navigationEndpoint\"\:([^\}]+)##s) {
+				my $two = $2;
+				$self->{'artist'} = $1;
+				$self->{'albumartist'} = 'https://youtube.be' . $1  if ($two =~ m#\"url\"\:\"([^\"]+)#);
+			}
+			if ($html =~ s#\"videoDetails\"\:\{\"videoId\"\:\"([^\"]+)\"([^\}]+)##s) {
+				my $two = $2;
+				$self->{'id'} = $1;
+				$self->{'title'} = $1  if ($two =~ m#\"title\"\:\"([^\"]+)#);
+				$self->{'iconurl'} = $1  if ($two =~ m#\"thumbnails\"\:\[\{\"url\"\:\"([^\"]+)#);
+				$self->{'iconurl'} =~ s/\?.*$//;
+			}
+			if ($html =~ m#\"dateText\"\:\{([^\}]+)\}#s) {
+				my $one = $1;
+				$self->{'year'} = $1  if ($one =~ /(\d\d\d\d)/);
+			}
+			$self->{'articonurl'} = $1  if ($html =~ m#(?:\"CHANNEL\"\,\"image\"|\"videoOwnerRenderer\")\:\{\"thumbnails"\:\[\{\"url\"\:\"([^\"]+)#s);
+			print  "--YT:2 CHANNEL ICON URL1=".$self->{'articonurl'}."=\n"  if ($DEBUG);
+			unless ($self->{'articonurl'}) {
+				my $ownerstuff = $1  if ($html =~ m#\"videoOwnerRenderer\"\:\{([^\}]+)#s);
+				$self->{'articonurl'} = $1  if ($ownerstuff =~ /\"url\"\:\"([^\"]+)/);
+			}
+			print  "--YT:2 CHANNEL ICON URL2=".$self->{'articonurl'}."=\n"  if ($DEBUG);
+		} elsif (!$try && defined($self->{'_ytID'}) && $self->{'_ytID'}) {
+			print STDERR "--WE ARE NOT A YT PAGE, BUT ytID=".$self->{'_ytID'}."= SO WE WILL TRY AGAIN!\n"  if ($DEBUG);
+			++$try;
+			#WE'RE NOT A YOUTUBE PAGE, BUT WE HAVE THE YT ID, SO TRY TO FETCH IT FOR METADATA:
+			$url2fetch = 'https://youtube.be/watch?v=' . $self->{'_ytID'};
+			goto RETRYPAGE;
 		}
-		$html =~ s/\\\"/\&quot\;/gs;
-		if ($html =~ s#\]\}\,\"title\"\:\{\"runs\"\:\[\{\"text\"\:\"([^\"]+)\"\,\"navigationEndpoint\"\:([^\}]+)##s) {
-			my $two = $2;
-			$self->{'artist'} = $1;
-			$self->{'albumartist'} = 'https://www.youtube.com' . $1  if ($two =~ m#\"url\"\:\"([^\"]+)#);
-		}
-		if ($html =~ s#\"videoDetails\"\:\{\"videoId\"\:\"([^\"]+)\"([^\}]+)##s) {
-			my $two = $2;
-			$self->{'id'} = $1;
-			$self->{'title'} = $1  if ($two =~ m#\"title\"\:\"([^\"]+)#);
-			$self->{'iconurl'} = $1  if ($two =~ m#\"thumbnails\"\:\[\{\"url\"\:\"([^\"]+)#);
-			$self->{'iconurl'} =~ s/\?.*$//;
-		}
-		if ($html =~ m#\"dateText\"\:\{([^\}]+)\}#s) {
-			my $one = $1;
-			$self->{'year'} = $1  if ($one =~ /(\d\d\d\d)/);
-		}
-		$self->{'articonurl'} = $1  if ($html =~ m#(?:\"CHANNEL\"\,\"image\"|\"videoOwnerRenderer\")\:\{\"thumbnails"\:\[\{\"url\"\:\"([^\"]+)#s);
-		print  "--YT:2 CHANNEL ICON URL1=".$self->{'articonurl'}."=\n"  if ($DEBUG);
-		unless ($self->{'articonurl'}) {
-			my $ownerstuff = $1  if ($html =~ m#\"videoOwnerRenderer\"\:\{([^\}]+)#s);
-			$self->{'articonurl'} = $1  if ($ownerstuff =~ /\"url\"\:\"([^\"]+)/);
-		}
-		print  "--YT:2 CHANNEL ICON URL2=".$self->{'articonurl'}."=\n"  if ($DEBUG);
 	}
 	$self->{'total'} = $self->{'cnt'};
 	$self->{'imageurl'} = $self->{'iconurl'};
