@@ -33,6 +33,7 @@ use vars qw(@ISA @EXPORT);
 
 my $DEBUG = 0;
 my $bummer = ($^O =~ /MSWin/);
+my $AGENT = "Mozilla/5.0 (X11; Linux x86_64; rv:91.0) Gecko/20100101 Firefox/91.0";
 
 sub new
 {
@@ -42,18 +43,20 @@ sub new
 	my $self = {'_objname' => $objname};
 
 	my $homedir = $bummer ? $ENV{'HOMEDRIVE'} . $ENV{'HOMEPATH'} : $ENV{'HOME'};
-	$homedir ||= $ENV{'LOGDIR'}  if ($ENV{'LOGDIR'});
+	$homedir ||= $ENV{'LOGDIR'}  if ($bummer && $ENV{'LOGDIR'});
 	$homedir =~ s#[\/\\]$##;
+	my $configdir = (defined $ENV{STREAMFINDER}) ? $ENV{STREAMFINDER} : "${homedir}/.config/StreamFinder";
+	$configdir =~ s#[\/\\]$##;
 	@{$self->{'_userAgentOps'}} = ();
-	foreach my $p ("${homedir}/.config/StreamFinder/config", "${homedir}/.config/StreamFinder/${objname}/config") {
+	foreach my $p ("${configdir}/config", "${configdir}/${objname}/config") {
 		if (open IN, $p) {
 			my ($atr, $val);
 			while (<IN>) {
 				chomp;
 				next  if (/^\s*\#/o);
 				($atr, $val) = split(/\s*\=\>\s*/o, $_, 2);
-				eval "\$self->{$atr} = $val";  #CATCH JSON-LIKE ARGS, IE. "arg => {key => value, ...}"
-				eval "\$self->{$atr} = \"\Q$val\E\""  if ($@);  #CATCH UNESCAPED ARGS, IE. "arg => str[with brackets,commas,etc.]"
+				eval "\$self->{'$atr'} = $val";  #CATCH JSON-LIKE ARGS, IE. "arg => {key => value, ...}"
+				eval "\$self->{'$atr'} = \"\Q$val\E\""  if ($@);  #CATCH UNESCAPED ARGS, IE. "arg => str[with brackets,commas,etc.]"
 			}
 			close IN;
 		}
@@ -63,7 +66,7 @@ sub new
 			proxy no_proxy)) {
 		push @{$self->{'_userAgentOps'}}, $i, $self->{$i}  if (defined $self->{$i});
 	}
-	push (@{$self->{'_userAgentOps'}}, 'agent', 'Mozilla/5.0 (X11; Linux x86_64; rv:68.0) Gecko/20100101 Firefox/68.0')
+	push (@{$self->{'_userAgentOps'}}, 'agent', $AGENT)
 			unless (defined $self->{'agent'});
 	$self->{'timeout'} = 10  unless (defined $self->{'timeout'});
 	$self->{'secure'} = 0    unless (defined $self->{'secure'});
